@@ -17,6 +17,8 @@ The return formatting depends on the size of the set:
 n: "first, second, …, <CONJUNCTION> last"
 ```
 
+This crate is `#![no_std]`-compatible.
+
 ## Examples
 
 The magic is accomplished with the [`OxfordJoin`] trait. Import that, and most
@@ -43,31 +45,41 @@ assert_eq!(set.oxford_or(), "Apples, Oranges, or Bananas");
 That's all, folks!
 */
 
-#![warn(clippy::filetype_is_file)]
-#![warn(clippy::integer_division)]
-#![warn(clippy::needless_borrow)]
-#![warn(clippy::nursery)]
-#![warn(clippy::pedantic)]
-#![warn(clippy::perf)]
-#![warn(clippy::suboptimal_flops)]
-#![warn(clippy::unneeded_field_pattern)]
-#![warn(macro_use_extern_crate)]
-#![warn(missing_copy_implementations)]
-#![warn(missing_debug_implementations)]
-#![warn(missing_docs)]
-#![warn(non_ascii_idents)]
-#![warn(trivial_casts)]
-#![warn(trivial_numeric_casts)]
-#![warn(unreachable_pub)]
-#![warn(unused_crate_dependencies)]
-#![warn(unused_extern_crates)]
-#![warn(unused_import_braces)]
+#![deny(unsafe_code)]
 
-use std::{
-	borrow::{
-		Borrow,
-		Cow,
-	},
+#![warn(
+	clippy::filetype_is_file,
+	clippy::integer_division,
+	clippy::needless_borrow,
+	clippy::nursery,
+	clippy::pedantic,
+	clippy::perf,
+	clippy::suboptimal_flops,
+	clippy::unneeded_field_pattern,
+	macro_use_extern_crate,
+	missing_copy_implementations,
+	missing_debug_implementations,
+	missing_docs,
+	non_ascii_idents,
+	trivial_casts,
+	trivial_numeric_casts,
+	unreachable_pub,
+	unused_crate_dependencies,
+	unused_extern_crates,
+	unused_import_braces,
+)]
+
+#![no_std]
+
+extern crate alloc;
+
+use alloc::{
+	borrow::Cow,
+	string::String,
+	vec::Vec,
+};
+use core::{
+	borrow::Borrow,
 	fmt,
 	ops::Deref,
 };
@@ -433,6 +445,7 @@ where T: AsRef<str> {
 	src.iter().map(|x| x.as_ref().len()).sum()
 }
 
+#[allow(unsafe_code)]
 /// # Join Two.
 fn join_two(a: &str, b: &str, glue: Conjunction) -> String {
 	let a = a.as_bytes();
@@ -455,6 +468,7 @@ fn join_two(a: &str, b: &str, glue: Conjunction) -> String {
 #[cfg(test)]
 mod tests {
 	use super::*;
+	use alloc::boxed::Box;
 	use brunch as _;
 
 	#[test]
